# squiz

View a Python object's direct and nested members.

## Installation

Install from [PyPI](https://pypi.org/project/squiz/):

```shell
pip install squiz
```

## Usage

<img src="https://github.com/morefigs/squiz/blob/main/examples/example.png"/>
